OC.L10N.register(
    "news",
    {
    "Unread articles" : "Ongeliesen Artikelen",
    "Download" : "Download",
    "Close" : "Zoumaachen",
    "Web address" : "Link",
    "No folder" : "Keen Dossier",
    "Folder name" : "Dossiers Numm:",
    "Username" : "Benotzernumm",
    "Password" : "Passwuert",
    "New folder" : "Neien Dossier",
    "Folder exists already!" : "Dësen Dossier gëtt et schonns!",
    "Credentials" : "Credentials",
    "Subscribe" : "Umellen",
    "Show all articles" : "All d'Artikelen uweisen",
    "Move" : "Verschieben",
    "Share" : "Deelen",
    "All articles" : "All Artikelen",
    "Explore" : "Erfuerschen",
    "Settings" : "Astellungen",
    "Documentation" : "Dokumentatioun",
    "Rename" : "Ëm-benennen",
    "Delete" : "Läschen",
    "by" : "vun",
    "Play audio" : "Toun ofspillen",
    "Download audio" : "Toun eroflueden",
    "Download video" : "Video eroflueden",
    "Open website" : "Oppe Websäit",
    "Folder" : "Dossier",
    "Jump to next article" : "Op den nächsten Artikel sprangen",
    "Jump to previous article" : "Op den Artikel vu virdru sprangen",
    "right" : "riets",
    "left" : "lénks",
    "Open article in new tab" : "Den Artikel an engem neien Tab opmaachen",
    "Refresh" : "Opfrëschen",
    "Load previous folder" : "Den Dossier vu virdrun lueden",
    "Load next folder" : "Den nächsten Dossier lueden"
},
"nplurals=2; plural=(n != 1);");
